About
=====

Panel is completely open source, available under a BSD license freely for both commercial and non-commercial use. Panel was originally developed with the support of `Anaconda Inc. <https://anaconda.com>`_ using funding from various commercial and government partners, and is now maintained by Anaconda developers and community contributors.

Panel is part of the `HoloViz <https://holoviz.org>`_ family of tools. The `holoviz.org <https://holoviz.org>`_ website shows how to use Panel together with other libraries to solve complex problems, with detailed tutorials and examples. You can see a variety of projects using Panel at `examples.pyviz.org <https://examples.pyviz.org>`_, and you can compare Panel to other available tools at `pyviz.org <https://pyviz.org>`_.

If you have any questions or usage issues visit the `Panel Discourse <https://discourse.holoviz.org/c/panel/>`_ site. If you are interested in contributing to Panel development to help address some of the `open issues <https://github.com/holoviz/panel/issues>`_, see our `developer instructions <https://pyviz-dev.github.io/panel/developer_guide/index.html>`_ to set up your development environment.

If you like Panel and have built something you want to share, tweet a link or screenshot of your latest creation at @Panel_org, along with any other library you used (@HoloViews, @Datashader, @BokehPlots, @Matplotlib, etc.). Thanks!


.. toctree::
   :titlesonly:
   :maxdepth: 2

   Comparisons <comparisons>
